@@ -492,6 +492,9 @@ class CommunicationType(models.Model):
     email_flag = models.BooleanField(default=False)
     default_flag = models.BooleanField(default=False)
 
+    def __str__(self):
+        return self.description
+
 
 class MyCompanyOther(models.Model):
     default_calendar = models.ForeignKey(
@@ -1569,6 +1572,13 @@ class Ticket(UpdateConnectWiseMixin, TimeStampedModel):
     tasks_completed = models.PositiveSmallIntegerField(blank=True, null=True)
     tasks_total = models.PositiveSmallIntegerField(blank=True, null=True)
     is_issue_flag = models.BooleanField(default=False)
+    contact_name = models.CharField(blank=True, null=True, max_length=62)
+    contact_phone_number = models.CharField(blank=True,
+                                            null=True, max_length=20)
+    contact_phone_extension = models.CharField(blank=True,
+                                               null=True, max_length=15)
+    contact_email_address = models.CharField(blank=True,
+                                             null=True, max_length=250)
 
     # Only used for creation, not synced.
     initial_description = models.CharField(
